<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="sr">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Програмски посредник</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Врста посредника</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>ИП адреса</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Прикључaк</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Опционо</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Обележи &quot;Користи посредника&quot; у контекстном изборнику програма Покретача Програма након поставке</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сачувај</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неважећа ИП адреса</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Неважећи прикључак</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Прекини везу</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сачувај</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Повезивање</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Прекини везу</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Заиста желите да обришете ова подешавања?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Жичана веза %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Врућа тачка</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Бежична веза %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>ПППоЕ веза %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Нови ВПН</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Врста ВПН-а</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>Л2ТП</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>ППТП</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>ОпенВПН</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>ОпенКонект</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>СнажниЛабуд</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>ВПНЦ</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Извези</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>ВПН Л2ТП %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>ВПН ППТП %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>ВПН  ВПНЦ %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>ВПН ОпенВПН %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>ВПН СнажниЛабуд %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>ВПН ОпенКонект  %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Програмски посредник</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Лична врућа тачка</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Детаљи мреже</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системски посредник</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Жична мрежа</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бежична мрежа</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>ВПН</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Авионски режим</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Жичана мрежна картица</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Додај мрежу</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Бежична мрежна картица</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Повежи се на скривену мрежу</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>ДСЛ</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Направи ПППоЕ Везу</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>ВПН стање</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Направи ВПН</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Увези ВПН</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Врста посредника</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Прилагођени УРЛ</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>ИП адреса</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Прикључaк</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Врућа тачка</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Направи врућу тачку</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Сучеље</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>МАК</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Опсег</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>ИПв4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основни ДНС</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Мрежна маска</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>ИПв6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Брзина протока</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Авионски режим</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>ДНС</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Неважећа ДНС адреса</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Унутрашња мрежа</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Није везан</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>МАК адр. уређаја</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Клонирана МАК адр.</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Прилагоди МТУ</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>МТУ</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Опште</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Опште</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Име већ постоји</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Аутоматски се повежи</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Врућа тачка</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Додај подешавања</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Направи врућу тачку</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>ИП адреса</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Дуплирана ИП адреса</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неважећа ИП адреса</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Неважећа мрежна маска</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Мрежна маска</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Дуплирана ИП адреса</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неважећа ИП адреса</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>ИПв4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>ИПв6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Аутоматски</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Занемари</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>ИП адреса</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Примени само у одговарајућим ресурсима</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Начин</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Мрежна маска</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неважећа ИП адреса</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Неважећа мрежна маска</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>ИП сукоб</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Начин</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>ИПв4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Аутоматски</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>ИПв6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Занемари</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Детаљи мреже</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>ДСЛ</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>ВПН</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системски посредник</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Програмски посредник</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Авионски режим</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Детаљи мреже</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>ИП сукоб</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Онемогућенo</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Аутоматски</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Подеси са Управником Мреже</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Лична врућа тачка</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>ПППоЕ</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Услуга</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>ППП</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Одбиј ЕАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Одбиј ПАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Одбиј ЦХАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Одбиј МСЦХАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Одбиј МСЦХАПв2 аутентификацију</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Без БСД компресије података</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Без подразумеване компресије података</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без ТЦП компресије заглавља</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Без протоколне компресије поља</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Без Адресно/Контролне компресије</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Шаљи ППП ехо пакете</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Употреби МППЕ</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit МППЕ</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>МППЕ са стањем</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Направи ПППоЕ везу</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>ППП</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Системски посредник</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сачувај</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Врста посредника</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Аутоматски</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Опционо</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Прикључaк</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>ХТТП посредник</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>ХТТПС посредник</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>ФТП посредник</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>СОКС посредник</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Игнориши поставке посредника за изнад наведене домаћине и домене</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Прилагођени УРЛ</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Безбедност</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>ТЛС</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>МД5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>ЛЕАП</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>ФАСТ</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Тунелни ТЛС</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Заштићени ЕАП</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Сачувај лозинку за овог корисника</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Сачувај лозинку за све кориснике</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Увек ме питај</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Онемогућенo</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Анониман</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Аутентификован</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Оба</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Аутоматски</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Верзија 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Верзија 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>ЕАП Аутент.</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Идентитет</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Опције лозинке</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Лични кључ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>ЦА сертификат</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Кориснички серт.</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Анонимни ИД</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Снабдевање</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>ПАК датотека</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Унутрашња аутент.</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>ПЕАП Верзија</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Лична лозинка</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Погрешна лозинка</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>ВЕП</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>ВПА/ВПА2 Лично</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Безбедност</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Кључ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Обавезно обезбеђење</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Погрешна лозинка</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>ВЕП</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>ВПА/ВПА2 Лично</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>ВПА/ВПА2 Пословни</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Дељени кључ</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Отворени систем</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Безбедност</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Идентификација</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Кључ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>ВПН напредно</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Прилагоди прикључак мрежног пролаза</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Прикључак мрежног пролаза</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Прилагоди интервал преговарања</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Интервал преговарања</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Користи ЛЗО компресију података</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Користи ТЦП везу</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Користи ТАП уређај</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Прилагодои тунелни МТУ</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>МТУ</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Прилагоди УДП величину фрагмената</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>УДП величина фрагмента</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Ограничи тунелни ТЦП МСС</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Насумични удаљени домаћини</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>ВПН напредно</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (подразумевано)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Безбедно (подразумевано)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Слабо</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>НАТ-Т Кад је доступно (подразуневано)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>НАТ-Т Увек</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco УДП</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Онемогућенo</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>ДХ група 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>ДХ група 2 (подразумевано)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>ДХ група 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Сервер (подразумевано)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>ДХ група 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Домен</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Пружалац</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Шифровање</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>НАТ Транзициони режим</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>ИКЕ ДХ група</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Прослеђена тајност</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Локални прикључак</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Искључи откривање неактивних вршњака</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>ВПН ИПсек</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Омогући ИПсек</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Име групе</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ИД групе</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Унапред дељени кључ</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Фаза1 Алгоритми</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Фаза2 Алгоритми</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>ВПН</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>ЦА сертификат</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Посредник</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Дозволи Cisco Безбедни Тројанац</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>ЦСД скрипта</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Кориснички серт.</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Лични кључ</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Користи ФСИД као фразу за пролаз</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>ВПН</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Сертификати (ТЛС)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Сертификати са лозинком (ТЛС)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Статични кључ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Сачувано</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Питај</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Није потребно</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Врста аутент.</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>ЦА сертификат</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Кориснички серт.</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Лични кључ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Опције лозинке</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Лична лозинка</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Прилагоди смер кључа</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Смер кључа</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Удаљени ИП</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Локални ИП</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>ВПН ППП</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Све доступно (подразумевано)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (мање безбедно)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (најбезбедније)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Одбиј ЕАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Одбиј ПАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Одбиј ЦХАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Одбиј МСЦХАП аутентификацију</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Одбиј МСЦХАПв2 аутентификацију</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Без БСД компресије података</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Без подразумеване компресије података</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без ТЦП компресије заглавља</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Без протоколне компресије поља</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Без Адресно/Контролне компресије</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Шаљи ППП ехо пакете</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Употреби МППЕ</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Безбедност</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>МППЕ са стањем</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>ВПН стање</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Направи ВПН</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Увези ВПН</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Грешка увоза</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Грешка датотеке</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>У реду</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>ВПН посредник</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Није потребно</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>ХТТП</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>СОКС</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Врста посредника</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>ИП сервера</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Прикључaк</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Увек пново покушавај при неуспеху</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>ЦА датотека</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Игнориши упозорења сертификата</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Користи ТЛС проширења имена домаћина</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>ВПН безбедност</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Шифровање</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>ХМАК Аутент.</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>ВПН</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Сачувано</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Питај</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Није потребно</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Опције лозинке</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>НТ Домен</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>ВПН посредник</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>ИП сервера</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Прикључaк</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>ВПН</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Лични кључ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>ССХ агент</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation> Паметна картица</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>ЕАП</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Унапред дељени кључ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>ЦА сертификат</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Врста аутент.</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Кориснички серт.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Затражи унутрашњу ИП адресу</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Наметни УДП капсулацију</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Користи ИП компресију</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Омогући прилагођене шифарске предлоге</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>ИКЕ</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ЕСП</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>ВПН ТЛС аутентификација</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Клијент</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Подударање субјеката</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Врста удаљеног сертификата</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Датотека кључа</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Прилагоди смер кључа</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Смер кључа</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>ВПН</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неважећи мрежни пролаз</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Сачувано</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Питај</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Није потребно</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Мрежни пролаз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Опције лозинке</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Име групе</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Лозинка групе</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Користи хибридну аутентификацију</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>ЦА датотека</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Прво укључите мрежни кабл</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Жичана мрежна картица</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Додај мрежу</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Изабери подешавања</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Бежична мрежна картица</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Затвори врућу тачку</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Прво онемогућите врућу тачку ако желите да се повежете на бежичну мрежу</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Повежи се на скривену мрежу</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>ВЛАН</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Није везан</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>ССИД</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Неопходно</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>МАК адр. уређаја</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Прилагоди МТУ</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>МТУ</translation>
    </message>
</context>
</TS>